==> haskell-authenticate-1.3.5.2-105-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-authenticate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 authenticate
version:              1.3.5.2
visibility:           public
id:                   authenticate-1.3.5.2-HcES75jOEFT9BxVTcTNkWP
key:                  authenticate-1.3.5.2-HcES75jOEFT9BxVTcTNkWP
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman, Hiromi Ishii, Arash Rouhani
stability:            Stable
homepage:             http://github.com/yesodweb/authenticate
synopsis:             Authentication methods for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate>.

category:             Web
abi:                  59bfbad282a41b75a1c9c93b1415719e
exposed:              True
exposed-modules:
    Web.Authenticate.BrowserId Web.Authenticate.OpenId
    Web.Authenticate.OpenId.Providers Web.Authenticate.Rpxnow

hidden-modules:
    Web.Authenticate.Internal OpenId2.Discovery OpenId2.Normalization
    OpenId2.Types OpenId2.XRDS

import-dirs:          /usr/lib/ghc-9.4.8/site-local/authenticate-1.3.5.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/authenticate-1.3.5.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/authenticate-1.3.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-authenticate
hs-libraries:         HSauthenticate-1.3.5.2-HcES75jOEFT9BxVTcTNkWP
depends:
    aeson-2.1.2.1-LDBL5bcX1HC79scYyh3opi
    attoparsec-0.14.4-HXvPhgAZIYuDm9YtcrLhPL
    attoparsec-aeson-2.1.0.0-BXnsnLtFrsADjrzh6mmwkA base-4.17.2.1
    blaze-builder-0.4.2.3-1WUo1omsOYUH2PSkelI6MS bytestring-0.11.5.3
    case-insensitive-1.2.1.0-3jbMOlKTiDn4NCqaBZ47Ne
    conduit-1.3.6.1-AL3EmwxQHuQ1mZT9WLAkFR containers-0.6.7
    html-conduit-1.3.2.2-Byvo4ht8tg8IaxnlEZO3Zi
    http-conduit-2.3.9.1-16gFKEPUkcU7pOEwwzAGYm
    http-types-0.12.4-3FyJu2Ux8ftJoanRheHyWI
    network-uri-2.6.4.2-EjZpKZ4F93eKYvVi9AsGV0
    resourcet-1.2.6-BEi0OW4T0Qo1xg4KkAo7Sv text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-2kG5VEC3Gy42AwINT9WJ9w
    xml-conduit-1.9.1.4-5DeSVAXqJ1xJGgslyd8Cwp

haddock-interfaces:
    /usr/share/doc/haskell-authenticate/html/authenticate.haddock

haddock-html:         /usr/share/doc/haskell-authenticate/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-authenticate-1.3.5.2-106-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-authenticate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 authenticate
version:              1.3.5.2
visibility:           public
id:                   authenticate-1.3.5.2-DZDIOhABsThH0jr7DxIYlF
key:                  authenticate-1.3.5.2-DZDIOhABsThH0jr7DxIYlF
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman, Hiromi Ishii, Arash Rouhani
stability:            Stable
homepage:             http://github.com/yesodweb/authenticate
synopsis:             Authentication methods for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate>.

category:             Web
abi:                  74130f59a30af5955a4787ea09d87205
exposed:              True
exposed-modules:
    Web.Authenticate.BrowserId Web.Authenticate.OpenId
    Web.Authenticate.OpenId.Providers Web.Authenticate.Rpxnow

hidden-modules:
    Web.Authenticate.Internal OpenId2.Discovery OpenId2.Normalization
    OpenId2.Types OpenId2.XRDS

import-dirs:          /usr/lib/ghc-9.4.8/site-local/authenticate-1.3.5.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/authenticate-1.3.5.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/authenticate-1.3.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-authenticate
hs-libraries:         HSauthenticate-1.3.5.2-DZDIOhABsThH0jr7DxIYlF
depends:
    aeson-2.1.2.1-17AWhWkbfJE926UMi0wPlA
    attoparsec-0.14.4-GkPzleiGSjl3NaBuhMDecM
    attoparsec-aeson-2.1.0.0-27aAa7AE1Ro6HkruGBXWaJ base-4.17.2.1
    blaze-builder-0.4.2.3-1WUo1omsOYUH2PSkelI6MS bytestring-0.11.5.3
    case-insensitive-1.2.1.0-3jbMOlKTiDn4NCqaBZ47Ne
    conduit-1.3.6.1-HwOUBFINqL9Hdg9Zavx6kP containers-0.6.7
    html-conduit-1.3.2.2-HbItAwRAE0xL7ec6frrh0G
    http-conduit-2.3.9.1-DqShVLJbBLLKO72a6CI2kc
    http-types-0.12.4-6IzIilaA47l58TRShghvhm
    network-uri-2.6.4.2-EjZpKZ4F93eKYvVi9AsGV0
    resourcet-1.2.6-BEi0OW4T0Qo1xg4KkAo7Sv text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-2kG5VEC3Gy42AwINT9WJ9w
    xml-conduit-1.9.1.4-1XbN0ypGG1ZKTuVRFIjLWV

haddock-interfaces:
    /usr/share/doc/haskell-authenticate/html/authenticate.haddock

haddock-html:         /usr/share/doc/haskell-authenticate/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
